@@ -1,8 +1,8 @@
 !== Monitor of CPU TIME
 !
 ! Authors::   Yasuhiro MORIKAWA
-! Version::   $Id: dc_clock.f90,v 1.21 2008-07-16 19:21:36 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20080720 $
+! Version::   $Id: dc_clock.f90,v 1.22 2008-07-28 09:51:14 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20080729 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2006. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -97,7 +97,7 @@ module dc_clock
   !   Get, EvalSec, toChar, Predict
 
   use dc_types, only: STRING
-  use dc_trace, only: BeginSub, EndSub
+  use dc_trace, only: BeginSub, EndSub, DbgMessage
   use dc_date_types, only: DC_DIFFTIME, DC_DATETIME
   implicit none
   private
@@ -235,8 +235,8 @@ module dc_clock
 
 
   character(*), parameter:: version = &
-    & '$Name: gt4f90io-20080720 $' // &
-    & '$Id: dc_clock.f90,v 1.21 2008-07-16 19:21:36 morikawa Exp $'
+    & '$Name: gt4f90io-20080729 $' // &
+    & '$Id: dc_clock.f90,v 1.22 2008-07-28 09:51:14 morikawa Exp $'
 
 contains
 
@@ -252,13 +252,12 @@ contains
     implicit none
     type(CLOCK), intent(out):: clk
     character(*), intent(in):: name
-    character(STRING):: endsub_msg
     character(*), parameter:: subname = 'DCClockCreate'
   continue
     call BeginSub(subname, 'name=%c', c1=trim(name), version=version)
     if (clk % initialized) then
       call MessageNotify('W', subname, 'This argument (type CLOCK) is already initialized.')
-      endsub_msg = 'already initialized'
+      call DbgMessage('already initialized')
       goto 999
     end if
     clk % name = name
@@ -266,9 +265,9 @@ contains
     clk % start_time = - 1.0
     clk % initialized = .true.
     call DCDateTimeCreate(clk % start_date)
-    endsub_msg = 'normal initialized'
+    call DbgMessage('normal initialized')
 999 continue
-    call EndSub(subname, endsub_msg)
+    call EndSub(subname)
   end subroutine DCClockCreate0
 
   subroutine DCClockClose0(clk)
@@ -300,14 +299,14 @@ contains
     ! ץ³Ԥޤ.
     !
     use dc_message, only: MessageNotify
-    use dc_string, only: toChar, CPrintf
+    use dc_string, only: toChar
     use dc_types, only: DP
     use dc_error, only: StoreError, DC_ENOTINIT, DC_NOERR
     use dc_date, only: assignment(=), EvalSec
     implicit none
     type(CLOCK), intent(inout):: clk
     logical, intent(out), optional:: err
-    character(STRING):: endsub_msg, cause_c
+    character(STRING):: cause_c
     real(DP):: start_time
     integer:: stat
     character(*), parameter:: subname = 'DCClockStart'
@@ -317,17 +316,17 @@ contains
     cause_c = 'CLOCK'
     if (.not. clk % initialized) then
       call MessageNotify('W', subname, 'Call Create before Start in dc_clock.')
-      endsub_msg = 'Ignored because input argument was not initialized.'
+      call DbgMessage('Ignored because input argument was not initialized.')
       stat = DC_ENOTINIT
       goto 999
     end if
     call cpu_time(start_time)
     clk % start_time = start_time
-    endsub_msg = CPrintf('name=%c, cpu_time=%f', &
-      & c1=trim(clk % name), d=(/EvalSec(clk % start_time)/))
+    call DbgMessage('name=%c, cpu_time=%f', &
+      & c1=trim(clk % name), d=(/EvalSec(clk % start_time)/) )
 999 continue
     call StoreError(stat, subname, err, cause_c)
-    call EndSub(subname, endsub_msg)
+    call EndSub(subname)
   end subroutine DCClockStart0
 
 
@@ -342,7 +341,7 @@ contains
     ! ץ³Ԥޤ.
     !
     use dc_message, only: MessageNotify
-    use dc_string, only: toChar, CPrintf
+    use dc_string, only: toChar
     use dc_error, only: StoreError, DC_ENOTINIT, DC_NOERR
     use dc_date, only: EvalSec, assignment(=), operator(+), operator(-)
     use dc_date_types, only: DC_DIFFTIME
@@ -350,7 +349,7 @@ contains
     implicit none
     type(CLOCK), intent(inout):: clk
     logical, intent(out), optional:: err
-    character(STRING):: endsub_msg, cause_c
+    character(STRING):: cause_c
     type(DC_DIFFTIME):: stop_timediff
     real:: stop_time
     integer:: stat
@@ -361,12 +360,12 @@ contains
     cause_c = 'CLOCK'
     if (.not. clk % initialized) then
       call MessageNotify('W', subname, 'Call Create before Stop in dc_clock.')
-      endsub_msg = 'Ignored because input argument was not initialized.'
+      call DbgMessage('Ignored because input argument was not initialized.')
       stat = DC_ENOTINIT
       goto 999
     elseif (EvalSec(clk % start_time) < 0.0_DP) then
       call MessageNotify('W', subname, 'Call Start before Stop in dc_clock.')
-      endsub_msg = 'Ignored because input argument was not started.'
+      call DbgMessage('Ignored because input argument was not started.')
       goto 999
     end if
     call cpu_time(stop_time)
@@ -374,11 +373,11 @@ contains
     clk % elapsed_time = clk % elapsed_time &
       & + stop_timediff - clk % start_time
     clk % start_time = - 1.0
-    endsub_msg = CPrintf('name=%c, cpu_time=%r, elapsed_time=%f', &
+    call DbgMessage('name=%c, cpu_time=%r, elapsed_time=%f', &
       & c1=trim(clk % name), r=(/stop_time/), d=(/EvalSec(clk % elapsed_time)/))
 999 continue
     call StoreError(stat, subname, err, cause_c)
-    call EndSub(subname, endsub_msg)
+    call EndSub(subname)
   end subroutine DCClockStop0
 
   subroutine DCClockGetR(clk, sec, err) !:doc-priority 40:
@@ -400,7 +399,7 @@ contains
     type(CLOCK), intent(in):: clk
     real, intent(out):: sec
     logical, intent(out), optional:: err
-    character(STRING):: endsub_msg, cause_c
+    character(STRING):: cause_c
     integer:: stat
     character(*), parameter:: subname = 'DCClockGetR'
   continue
@@ -409,16 +408,16 @@ contains
     cause_c = 'CLOCK'
     if (.not. clk % initialized) then
       call MessageNotify('W', subname, 'Call Create before Get in dc_clock.')
-      endsub_msg = 'Ignored because input argument was not initialized.'
+      call DbgMessage('Ignored because input argument was not initialized.')
       stat = DC_ENOTINIT
       goto 999
     end if
     sec = real(EvalSec(clk % elapsed_time))
-    endsub_msg = CPrintf('name=%c, return sec=<%r>', &
+    call DbgMessage('name=%c, return sec=<%r>', &
       & c1=trim(clk % name), r=(/sec/))
 999 continue
     call StoreError(stat, subname, err, cause_c)
-    call EndSub(subname, endsub_msg)
+    call EndSub(subname)
   end subroutine DCClockGetR
 
   subroutine DCClockGetD(clk, sec, err) !:doc-priority 60:
@@ -441,7 +440,7 @@ contains
     type(CLOCK), intent(in):: clk
     real(DP), intent(out):: sec
     logical, intent(out), optional:: err
-    character(STRING):: endsub_msg, cause_c
+    character(STRING):: cause_c
     integer:: stat
     character(*), parameter:: subname = 'DCClockGetD'
   continue
@@ -450,16 +449,16 @@ contains
     cause_c = 'CLOCK'
     if (.not. clk % initialized) then
       call MessageNotify('W', subname, 'Call Create before Get in dc_clock.')
-      endsub_msg = 'Ignored because input argument was not initialized.'
+      call DbgMessage('Ignored because input argument was not initialized.')
       stat = DC_ENOTINIT
       goto 999
     end if
     sec = EvalSec(clk % elapsed_time)
-    endsub_msg = CPrintf('name=%c, return sec=<%f>', &
+    call DbgMessage('name=%c, return sec=<%f>', &
       & c1=trim(clk % name), d=(/sec/))
 999 continue
     call StoreError(stat, subname, err, cause_c)
-    call EndSub(subname, endsub_msg)
+    call EndSub(subname)
   end subroutine DCClockGetD
 
   function DCClockEvalSecD(clk) result(result)
@@ -533,7 +532,7 @@ contains
                               ! Indent of displayed messages.
     logical, intent(out), optional:: err
     integer:: out_unit
-    character(STRING):: endsub_msg, cause_c
+    character(STRING):: cause_c
     integer:: stat
     integer:: indent_len
     character(STRING):: indent_str
@@ -544,7 +543,7 @@ contains
     cause_c = 'CLOCK'
     if (.not. clk % initialized) then
       call MessageNotify('W', subname, 'Call Create before PutLine in dc_clock.')
-      endsub_msg = 'Ignored because input argument was not initialized.'
+      call DbgMessage('Ignored because input argument was not initialized.')
       stat = DC_ENOTINIT
       goto 999
     end if
@@ -568,11 +567,11 @@ contains
       & d=(/EvalSec(clk % elapsed_time)/), &
       & c2=trim(fit_unit_value(clk % elapsed_time)), &
       & c3=trim(toChar(clk % start_date)))
-    endsub_msg = CPrintf('name=%c, output to device number %d', &
+    call DbgMessage('name=%c, output to device number %d', &
       & c1=trim(clk % name), i=(/out_unit/))
 999 continue
     call StoreError(stat, subname, err, cause_c)
-    call EndSub(subname, endsub_msg)
+    call EndSub(subname)
   end subroutine DCClockPutLine0
 
   subroutine DCClockResult0(clks, unit, total_auto, clk_total, total_name, err)
@@ -612,7 +611,7 @@ contains
     character(*), intent(in), optional:: total_name
     integer:: out_unit, i, clks_size
     character(20):: clk_name
-    character(STRING):: endsub_msg, cause_c
+    character(STRING):: cause_c
     character(STRING):: total_name_work
     type(CLOCK):: clk_auto_total
     logical:: total_print_complete
@@ -628,7 +627,7 @@ contains
     do i = 1, clks_size
       if (.not. clks(i) % initialized) then
         call MessageNotify('W', subname, 'Call Create before Result in dc_clock.')
-        endsub_msg = 'Ignored because input argument was not initialized.'
+        call DbgMessage('Ignored because input argument was not initialized.')
         stat = DC_ENOTINIT
         goto 999
       end if
@@ -690,11 +689,11 @@ contains
       end if
     end if
 
-    endsub_msg = CPrintf('total results, output to device number %d', &
+    call DbgMessage('total results, output to device number %d', &
       & i=(/out_unit/))
 999 continue
     call StoreError(stat, subname, err, cause_c)
-    call EndSub(subname, endsub_msg)
+    call EndSub(subname)
   end subroutine DCClockResult0
 
   function result_value_form(value) result(result)
@@ -872,7 +871,7 @@ contains
     type(CLOCK), intent(inout):: clk
     character(*), intent(in):: name
     logical, intent(out), optional:: err
-    character(STRING):: endsub_msg, cause_c
+    character(STRING):: cause_c
     integer:: stat
     character(*), parameter:: subname = 'DCClockSetName'
   continue
@@ -881,15 +880,15 @@ contains
     cause_c = 'CLOCK'
     if (.not. clk % initialized) then
       call MessageNotify('W', subname, 'Call Create before Set_Name in dc_clock.')
-      endsub_msg = 'Ignored because input argument was not initialized.'
+      call DbgMessage('Ignored because input argument was not initialized.')
       stat = DC_ENOTINIT
       goto 999
     end if
     clk % name = name
-    endsub_msg = CPrintf('set new name "%c"', c1=trim(clk % name))
+    call DbgMessage('set new name "%c"', c1=trim(clk % name))
 999 continue
     call StoreError(stat, subname, err, cause_c)
-    call EndSub(subname, endsub_msg)
+    call EndSub(subname)
   end subroutine DCClockSetName0
 
   subroutine DCClockPredict0(clk, progress, unit, err)
@@ -933,7 +932,7 @@ contains
     real, intent(in):: progress
     integer, intent(in), optional:: unit
     logical, intent(out), optional:: err
-    character(STRING):: endsub_msg, cause_c
+    character(STRING):: cause_c
     integer:: stat, out_unit
     type(DC_DIFFTIME):: remain_diff
     type(DC_DATETIME):: comp_date, cur_date
@@ -948,7 +947,7 @@ contains
     cause_c = 'CLOCK'
     if (.not. clk % initialized) then
       call MessageNotify('W', subname, 'Call Create before Predict in dc_clock.')
-      endsub_msg = 'Ignored because input argument was not initialized.'
+      call DbgMessage('Ignored because input argument was not initialized.')
       stat = DC_ENOTINIT
       goto 999
     end if
@@ -995,7 +994,7 @@ contains
 
 999 continue
     call StoreError(stat, subname, err, cause_c)
-    call EndSub(subname, endsub_msg)
+    call EndSub(subname)
   end subroutine DCClockPredict0
 
 
