@@ -1,8 +1,8 @@
 !== dc_date.f90 - դӻ˴ؤ³󶡤⥸塼
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dc_date.f90,v 1.25 2008-06-05 04:42:12 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20080720 $
+! Version::   $Id: dc_date.f90,v 1.26 2008-07-25 14:36:37 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20080729 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 
@@ -223,14 +223,23 @@ module dc_date
       real(DP),intent(in), optional:: sec, day_seconds
     end subroutine DCDiffTimeCreate1
 
-    subroutine DCDiffTimeCreate2(diff, value, unit, err) !:doc-priority 70:
+    subroutine DCDiffTimeCreate2D(diff, value, unit, err) !:doc-priority 70:
       use dc_types, only: DP
       use dc_date_types, only: DC_DIFFTIME
       type(DC_DIFFTIME), intent(out) :: diff
       real(DP), intent(in) :: value
       character(*), intent(in) :: unit
       logical, intent(out), optional :: err
-    end subroutine DCDiffTimeCreate2
+    end subroutine DCDiffTimeCreate2D
+
+    subroutine DCDiffTimeCreate2R(diff, value, unit, err) !:doc-priority 80:
+      use dc_date_types, only: DC_DIFFTIME
+      type(DC_DIFFTIME), intent(out) :: diff
+      real, intent(in) :: value
+      character(*), intent(in) :: unit
+      logical, intent(out), optional :: err
+    end subroutine DCDiffTimeCreate2R
+
   end interface
 
   interface DCDateTimePutLine
