@@ -3,8 +3,8 @@
 != Error handling
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dc_error.f90,v 1.32 2008-07-20 15:09:44 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20080720 $
+! Version::   $Id: dc_error.f90,v 1.37 2008-07-29 18:26:20 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20080729 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -424,6 +424,18 @@ module dc_error
   ! -510    :: [ <b>HST_EALREADYPROGRESS   </b> ] 
   !            <b></b> :: already progressed by (<i>cause_c</i>)
   !
+  ! -511    :: [ <b>HST_EBADSLICE   </b> ] 
+  !            <b></b> :: slice options are invalid (<i>cause_c</i>)
+  !
+  ! -512    :: [ <b>HST_EBADNEWFILEINT   </b> ] 
+  !            <b></b> :: invalid newfile interval (<i>cause_c</i>)
+  !
+  ! -513    :: [ <b>HST_EMAXDIMSDEPENDED   </b> ] 
+  !            <b></b> :: variable (<i>cause_c</i>) depends on (<i>cause_i</i>) dimensions
+  !
+  ! -514    :: [ <b>HST_EINDIVISIBLE   </b> ] 
+  !            <b></b> :: (<i>cause_c</i>) can not be divided
+  !
   !=== gt4f90io ξγĥΤͽ󤷤Ƥ륨顼
   !=== Reserved error codes for future extensions of gt4f90io
   !
@@ -538,6 +550,11 @@ module dc_error
   integer, parameter, public:: HST_ENOAXISNAME       = -508
   integer, parameter, public:: HST_EVARINUSE         = -509
   integer, parameter, public:: HST_EALREADYPROGRESS  = -510
+  integer, parameter, public:: HST_EBADSLICE         = -511
+  integer, parameter, public:: HST_EBADNEWFILEINT    = -512
+  integer, parameter, public:: HST_EMAXDIMSDEPENDED  = -513
+  integer, parameter, public:: HST_EINDIVISIBLE      = -514
+
 
   !
   ! -1000 ʲ: 桼
@@ -691,6 +708,17 @@ contains
       msg = ' variable name (' // trim(cause_string) // ') is already used'
     case(HST_EALREADYPROGRESS)
       msg = ' already progressed by (' // trim(cause_string) // ')'
+    case(HST_EBADSLICE)
+      msg = ' slice options are invalid (' // trim(cause_string) // ')'
+    case(HST_EBADNEWFILEINT)
+      msg = ' invalid newfile interval (' // trim(cause_string) // ')'
+    case(HST_EMAXDIMSDEPENDED)
+      write(message, '("(", i4, ")")') cause_int
+      msg = trim(message)
+      msg = ' variable (' // trim(cause_string) // ') depends on ' // trim(message) // ' dimensions'
+    case(HST_EINDIVISIBLE)
+      msg = ' (' // trim(cause_string) // ') can not be divided'
+
       !
       !
       ! -1000 ʲ: 桼
@@ -829,6 +857,11 @@ contains
                               ! å 
                               ! Integer message
   continue
+    if (present(err)) then
+      err = (number /= DC_NOERR)
+      return
+    endif
+    if (number == DC_NOERR) return
     errno = number
     cause_location = where
     if (present(cause_c)) then
@@ -842,11 +875,6 @@ contains
     else
       cause_int_valid = .false.
     end if
-    if (present(err)) then
-      err = (number /= DC_NOERR)
-      return
-    endif
-    if (number == DC_NOERR) return
     call DumpError
   end subroutine StoreError
 
