@@ -1,8 +1,8 @@
 !== dc_trace.f90 - ǥХåѥ⥸塼
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dc_trace.f90,v 1.9 2007-08-12 05:26:06 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20080720 $
+! Version::   $Id: dc_trace.f90,v 1.11 2008-07-28 14:28:47 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20080729 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -396,6 +396,7 @@ contains
     logical :: print_version
     integer :: alloc_size
   continue
+    if ( dbg < 0 ) return
     if (lfirst) call initialize
     if (debug()) then
       name_ver = name
@@ -483,6 +484,7 @@ contains
     character(*), intent(in), optional:: ca(:)
     character(STRING):: cbuf
   continue
+    if ( dbg < 0 ) return
     if (lfirst) call initialize
     ! call errtra ! --- for Fujitsu debug
     if (level <= 0) then
@@ -536,7 +538,7 @@ contains
     character(STRING):: meshead_tmp
     integer          :: meshead_len
   continue
-    if (.not. debug()) return
+    if ( dbg < 0 ) return
     cbuf = cprintf(fmt, i, r, d, L, n, c1, c2, c3, ca)
     if (level < 1) then
       meshead_tmp = ''
@@ -595,7 +597,7 @@ contains
     character(STRING):: meshead_tmp
     integer          :: meshead_len
   continue
-    if (.not. debug()) return
+    if ( dbg < 0 ) return
 
     ! 
     unit    = ''
@@ -696,7 +698,7 @@ contains
     integer              :: j
 
   continue
-    if (.not. debug()) return
+    if ( dbg < 0 ) return
 
     if (present(multi)) then
       allocate( total(size(multi)+1) )
@@ -730,7 +732,7 @@ contains
     integer              :: k
 
   continue
-    if (.not. debug()) return
+    if ( dbg < 0 ) return
 
     if (present(multi)) then
       allocate( total(size(multi)+1) )
