@@ -1,8 +1,8 @@
 !== Sample program for gt4_history/gt4f90io
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: histaxis.f90,v 1.5 2006-01-15 19:09:47 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20080720 $
+! Version::   $Id: histaxis.f90,v 1.7 2008-07-27 22:20:26 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20080729 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../COPYRIGHT]
 !
@@ -12,7 +12,11 @@ program histaxis
   ! "HistoryAddVariable2", "HistoryPut",
   ! "HistorySetTime", "HistoryClose".
   !
-  use gt4f90io
+  use gt4_history, only: Copy, Create, &
+    & HistoryAddVariable, HistoryAxisAddAttr, HistoryAxisCreate, &
+    & HistoryClose, HistoryCreate, HistoryPut, HistoryVarinfoAddAttr, &
+    & Inquire, Put_Attr, HistoryVarinfoInitialized, HistoryVarinfoClear
+  use dc_test, only: AssertEqual
   use dc_trace, only: SetDebug, DbgMessage
   use dc_types, only:  TOKEN, STRING
   use gt4_history
@@ -37,7 +41,11 @@ continue
   call Create(axes1(1), 'time', 0, 'time', 's @ 2001-12-16T10:00', 'float')
 
   !----- ѿλ -----
+  call AssertEqual('HistoryVarinfoInitialized Test 1', &
+    & answer=.false., check = HistoryVarinfoInitialized( var1 ) )
   call Create(var1, 'u', (/'time'/), 'any quantity', 'non-dimensional', 'float')
+  call AssertEqual('HistoryVarinfoInitialized Test 2', &
+    & answer=.true., check = HistoryVarinfoInitialized( var1 ) )
 
   call HistoryCreate(file='xhistaxis/xhistaxis1.nc', &
     & title='gt4_history HistoryCreate2 test 1',   &
@@ -79,6 +87,7 @@ continue
     & origin=0.0, interval=0.0) 
   call Create(var2, 'u', dims1(:), 'foo quantity', 'm/s', 'float')
   call HistoryAddVariable(varinfo=var2)
+  call HistoryVarinfoClear(varinfo=var2)
   call Create(var2, 'v', dims1(:), 'foo quantity', 'm/s', 'float')
   call HistoryAddVariable(varinfo=var2)
   call HistoryPut('x', (/0.0, 1.0, 2.0/))
